@@ -10,7 +10,7 @@ test_that("stan inputs are built correctly", {
   y <- matrix(c(1,0,0,1,1,1,0,0,1), nrow=3, byrow=T)
   resp <- ubmsResponse(y, "binomial", "P")
 
-  inp <- build_stan_inputs("occu", resp, sl)
+  inp <- build_stan_inputs("occu", resp, sl, log_lik=FALSE)
   expect_is(inp, "list")
   expect_equal(names(inp), c("stan_data", "pars"))
 
@@ -33,6 +33,10 @@ test_that("parameter list for stan is generated correctly",{
   sl <- ubmsSubmodelList(state, det)
   expect_equal(get_pars(det), "beta_det")
   expect_equal(get_pars(state), c("beta_state", "b_state", "sigma_state"))
+  expect_equal(get_pars(sl, "occu", log_lik=FALSE),
+               c("beta_state", "b_state", "sigma_state", "beta_det"))
+  expect_equal(get_pars(sl, "occu", log_lik=TRUE),
+               c("beta_state", "b_state", "sigma_state", "beta_det", "log_lik"))
 })
 
 test_that("get_stan_data pulls necessary info from response object",{
@@ -126,6 +130,11 @@ test_that("get_nrandom returns number of levels of each grouping variable",{
                "Nested random effects (using / and :) are not supported", fixed=TRUE)
 })
 
+test_that("get_nrandom handles situation where a factor level is missing in data",{
+  dat <- data.frame(x=factor(c("a","b","c"),levels=letters[1:4]))
+  expect_equivalent(get_nrandom(~(1|x), dat), 4)
+})
+
 test_that("split_formula works",{
   inp <- ~1~1
   expect_equal(split_formula(inp), list(det=~1, state=~1))
